==> citrus-http-4.0.2-sources.jar: org/citrusframework/model/testcase/http/SendRequestModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.3 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.http;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für anonymous complex type.
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <choice>
 *           <element name="GET" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="POST" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="PUT" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="DELETE" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="HEAD" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="OPTIONS" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="TRACE" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="PATCH" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *         </choice>
 *         <element name="extract" minOccurs="0">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <sequence>
 *                   <element name="header" maxOccurs="unbounded" minOccurs="0">
 *                     <complexType>
 *                       <complexContent>
 *                         <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                           <attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                           <attribute name="variable" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                         </restriction>
 *                       </complexContent>
 *                     </complexType>
 *                   </element>
 *                 </sequence>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *       </sequence>
 *       <attribute name="client" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="uri" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="actor" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="fork" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "patch",
    "trace",
    "options",
    "head",
    "delete",
    "put",
    "post",
    "get",
    "extract"
})
@XmlRootElement(name = "send-request")
public class SendRequestModel {

    @XmlElement(name = "PATCH")
    protected ClientRequestType patch;
    @XmlElement(name = "TRACE")
    protected ClientRequestType trace;
    @XmlElement(name = "OPTIONS")
    protected ClientRequestType options;
    @XmlElement(name = "HEAD")
    protected ClientRequestType head;
    @XmlElement(name = "DELETE")
    protected ClientRequestType delete;
    @XmlElement(name = "PUT")
    protected ClientRequestType put;
    @XmlElement(name = "POST")
    protected ClientRequestType post;
    @XmlElement(name = "GET")
    protected ClientRequestType get;
    protected SendRequestModel.Extract extract;
    @XmlAttribute(name = "client")
    protected String client;
    @XmlAttribute(name = "uri")
    protected String uri;
    @XmlAttribute(name = "actor")
    protected String actor;
    @XmlAttribute(name = "fork")
    protected Boolean fork;

    /**
     * Ruft den Wert der patch-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getPATCH() {
        return patch;
    }

    /**
     * Legt den Wert der patch-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setPATCH(ClientRequestType value) {
        this.patch = value;
    }

    /**
     * Ruft den Wert der trace-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getTRACE() {
        return trace;
    }

    /**
     * Legt den Wert der trace-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setTRACE(ClientRequestType value) {
        this.trace = value;
    }

    /**
     * Ruft den Wert der options-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getOPTIONS() {
        return options;
    }

    /**
     * Legt den Wert der options-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setOPTIONS(ClientRequestType value) {
        this.options = value;
    }

    /**
     * Ruft den Wert der head-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getHEAD() {
        return head;
    }

    /**
     * Legt den Wert der head-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setHEAD(ClientRequestType value) {
        this.head = value;
    }

    /**
     * Ruft den Wert der delete-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getDELETE() {
        return delete;
    }

    /**
     * Legt den Wert der delete-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setDELETE(ClientRequestType value) {
        this.delete = value;
    }

    /**
     * Ruft den Wert der put-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getPUT() {
        return put;
    }

    /**
     * Legt den Wert der put-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setPUT(ClientRequestType value) {
        this.put = value;
    }

    /**
     * Ruft den Wert der post-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getPOST() {
        return post;
    }

    /**
     * Legt den Wert der post-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setPOST(ClientRequestType value) {
        this.post = value;
    }

    /**
     * Ruft den Wert der get-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getGET() {
        return get;
    }

    /**
     * Legt den Wert der get-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setGET(ClientRequestType value) {
        this.get = value;
    }

    /**
     * Ruft den Wert der extract-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link SendRequestModel.Extract }
     *     
     */
    public SendRequestModel.Extract getExtract() {
        return extract;
    }

    /**
     * Legt den Wert der extract-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link SendRequestModel.Extract }
     *     
     */
    public void setExtract(SendRequestModel.Extract value) {
        this.extract = value;
    }

    /**
     * Ruft den Wert der client-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getClient() {
        return client;
    }

    /**
     * Legt den Wert der client-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setClient(String value) {
        this.client = value;
    }

    /**
     * Ruft den Wert der uri-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUri() {
        return uri;
    }

    /**
     * Legt den Wert der uri-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUri(String value) {
        this.uri = value;
    }

    /**
     * Ruft den Wert der actor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActor() {
        return actor;
    }

    /**
     * Legt den Wert der actor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActor(String value) {
        this.actor = value;
    }

    /**
     * Ruft den Wert der fork-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isFork() {
        return fork;
    }

    /**
     * Legt den Wert der fork-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setFork(Boolean value) {
        this.fork = value;
    }


    /**
     * <p>Java-Klasse für anonymous complex type.
     * 
     * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <sequence>
     *         <element name="header" maxOccurs="unbounded" minOccurs="0">
     *           <complexType>
     *             <complexContent>
     *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *                 <attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
     *                 <attribute name="variable" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
     *               </restriction>
     *             </complexContent>
     *           </complexType>
     *         </element>
     *       </sequence>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "headers"
    })
    public static class Extract {

        @XmlElement(name = "header")
        protected List<SendRequestModel.Extract.Header> headers;

        /**
         * Gets the value of the headers property.
         * 
         * <p>
         * This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the Jakarta XML Binding object.
         * This is why there is not a {@code set} method for the headers property.
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * <pre>
         *    getHeaders().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link SendRequestModel.Extract.Header }
         * 
         * 
         * @return
         *     The value of the headers property.
         */
        public List<SendRequestModel.Extract.Header> getHeaders() {
            if (headers == null) {
                headers = new ArrayList<>();
            }
            return this.headers;
        }


        /**
         * <p>Java-Klasse für anonymous complex type.
         * 
         * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.
         * 
         * <pre>{@code
         * <complexType>
         *   <complexContent>
         *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
         *       <attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
         *       <attribute name="variable" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
         *     </restriction>
         *   </complexContent>
         * </complexType>
         * }</pre>
         * 
         * 
         */
        @XmlAccessorType(XmlAccessType.FIELD)
        @XmlType(name = "")
        public static class Header {

            @XmlAttribute(name = "name", required = true)
            protected String name;
            @XmlAttribute(name = "variable", required = true)
            protected String variable;

            /**
             * Ruft den Wert der name-Eigenschaft ab.
             * 
             * @return
             *     possible object is
             *     {@link String }
             *     
             */
            public String getName() {
                return name;
            }

            /**
             * Legt den Wert der name-Eigenschaft fest.
             * 
             * @param value
             *     allowed object is
             *     {@link String }
             *     
             */
            public void setName(String value) {
                this.name = value;
            }

            /**
             * Ruft den Wert der variable-Eigenschaft ab.
             * 
             * @return
             *     possible object is
             *     {@link String }
             *     
             */
            public String getVariable() {
                return variable;
            }

            /**
             * Legt den Wert der variable-Eigenschaft fest.
             * 
             * @param value
             *     allowed object is
             *     {@link String }
             *     
             */
            public void setVariable(String value) {
                this.variable = value;
            }

        }

    }

}

==> citrus-http-4.1.0-sources.jar: org/citrusframework/model/testcase/http/SendRequestModel.java <==
//
// Diese Datei wurde mit der Eclipse Implementation of JAXB, v4.0.4 generiert 
// Siehe https://eclipse-ee4j.github.io/jaxb-ri 
// Änderungen an dieser Datei gehen bei einer Neukompilierung des Quellschemas verloren. 
//


package org.citrusframework.model.testcase.http;

import java.util.ArrayList;
import java.util.List;
import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java-Klasse für anonymous complex type.</p>
 * 
 * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <choice>
 *           <element name="GET" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="POST" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="PUT" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="DELETE" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="HEAD" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="OPTIONS" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="TRACE" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *           <element name="PATCH" type="{http://www.citrusframework.org/schema/http/testcase}ClientRequestType"/>
 *         </choice>
 *         <element name="extract" minOccurs="0">
 *           <complexType>
 *             <complexContent>
 *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 <sequence>
 *                   <element name="header" maxOccurs="unbounded" minOccurs="0">
 *                     <complexType>
 *                       <complexContent>
 *                         <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                           <attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                           <attribute name="variable" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
 *                         </restriction>
 *                       </complexContent>
 *                     </complexType>
 *                   </element>
 *                 </sequence>
 *               </restriction>
 *             </complexContent>
 *           </complexType>
 *         </element>
 *       </sequence>
 *       <attribute name="client" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="uri" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="actor" type="{http://www.w3.org/2001/XMLSchema}string" />
 *       <attribute name="fork" type="{http://www.w3.org/2001/XMLSchema}boolean" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "patch",
    "trace",
    "options",
    "head",
    "delete",
    "put",
    "post",
    "get",
    "extract"
})
@XmlRootElement(name = "send-request")
public class SendRequestModel {

    @XmlElement(name = "PATCH")
    protected ClientRequestType patch;
    @XmlElement(name = "TRACE")
    protected ClientRequestType trace;
    @XmlElement(name = "OPTIONS")
    protected ClientRequestType options;
    @XmlElement(name = "HEAD")
    protected ClientRequestType head;
    @XmlElement(name = "DELETE")
    protected ClientRequestType delete;
    @XmlElement(name = "PUT")
    protected ClientRequestType put;
    @XmlElement(name = "POST")
    protected ClientRequestType post;
    @XmlElement(name = "GET")
    protected ClientRequestType get;
    protected SendRequestModel.Extract extract;
    @XmlAttribute(name = "client")
    protected String client;
    @XmlAttribute(name = "uri")
    protected String uri;
    @XmlAttribute(name = "actor")
    protected String actor;
    @XmlAttribute(name = "fork")
    protected Boolean fork;

    /**
     * Ruft den Wert der patch-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getPATCH() {
        return patch;
    }

    /**
     * Legt den Wert der patch-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setPATCH(ClientRequestType value) {
        this.patch = value;
    }

    /**
     * Ruft den Wert der trace-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getTRACE() {
        return trace;
    }

    /**
     * Legt den Wert der trace-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setTRACE(ClientRequestType value) {
        this.trace = value;
    }

    /**
     * Ruft den Wert der options-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getOPTIONS() {
        return options;
    }

    /**
     * Legt den Wert der options-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setOPTIONS(ClientRequestType value) {
        this.options = value;
    }

    /**
     * Ruft den Wert der head-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getHEAD() {
        return head;
    }

    /**
     * Legt den Wert der head-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setHEAD(ClientRequestType value) {
        this.head = value;
    }

    /**
     * Ruft den Wert der delete-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getDELETE() {
        return delete;
    }

    /**
     * Legt den Wert der delete-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setDELETE(ClientRequestType value) {
        this.delete = value;
    }

    /**
     * Ruft den Wert der put-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getPUT() {
        return put;
    }

    /**
     * Legt den Wert der put-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setPUT(ClientRequestType value) {
        this.put = value;
    }

    /**
     * Ruft den Wert der post-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getPOST() {
        return post;
    }

    /**
     * Legt den Wert der post-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setPOST(ClientRequestType value) {
        this.post = value;
    }

    /**
     * Ruft den Wert der get-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link ClientRequestType }
     *     
     */
    public ClientRequestType getGET() {
        return get;
    }

    /**
     * Legt den Wert der get-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link ClientRequestType }
     *     
     */
    public void setGET(ClientRequestType value) {
        this.get = value;
    }

    /**
     * Ruft den Wert der extract-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link SendRequestModel.Extract }
     *     
     */
    public SendRequestModel.Extract getExtract() {
        return extract;
    }

    /**
     * Legt den Wert der extract-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link SendRequestModel.Extract }
     *     
     */
    public void setExtract(SendRequestModel.Extract value) {
        this.extract = value;
    }

    /**
     * Ruft den Wert der client-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getClient() {
        return client;
    }

    /**
     * Legt den Wert der client-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setClient(String value) {
        this.client = value;
    }

    /**
     * Ruft den Wert der uri-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUri() {
        return uri;
    }

    /**
     * Legt den Wert der uri-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUri(String value) {
        this.uri = value;
    }

    /**
     * Ruft den Wert der actor-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActor() {
        return actor;
    }

    /**
     * Legt den Wert der actor-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setActor(String value) {
        this.actor = value;
    }

    /**
     * Ruft den Wert der fork-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public Boolean isFork() {
        return fork;
    }

    /**
     * Legt den Wert der fork-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setFork(Boolean value) {
        this.fork = value;
    }


    /**
     * <p>Java-Klasse für anonymous complex type.</p>
     * 
     * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
     * 
     * <pre>{@code
     * <complexType>
     *   <complexContent>
     *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       <sequence>
     *         <element name="header" maxOccurs="unbounded" minOccurs="0">
     *           <complexType>
     *             <complexContent>
     *               <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *                 <attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
     *                 <attribute name="variable" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
     *               </restriction>
     *             </complexContent>
     *           </complexType>
     *         </element>
     *       </sequence>
     *     </restriction>
     *   </complexContent>
     * </complexType>
     * }</pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "headers"
    })
    public static class Extract {

        @XmlElement(name = "header")
        protected List<SendRequestModel.Extract.Header> headers;

        /**
         * Gets the value of the headers property.
         * 
         * <p>This accessor method returns a reference to the live list,
         * not a snapshot. Therefore any modification you make to the
         * returned list will be present inside the JAXB object.
         * This is why there is not a <CODE>set</CODE> method for the headers property.</p>
         * 
         * <p>
         * For example, to add a new item, do as follows:
         * </p>
         * <pre>
         * getHeaders().add(newItem);
         * </pre>
         * 
         * 
         * <p>
         * Objects of the following type(s) are allowed in the list
         * {@link SendRequestModel.Extract.Header }
         * </p>
         * 
         * 
         * @return
         *     The value of the headers property.
         */
        public List<SendRequestModel.Extract.Header> getHeaders() {
            if (headers == null) {
                headers = new ArrayList<>();
            }
            return this.headers;
        }


        /**
         * <p>Java-Klasse für anonymous complex type.</p>
         * 
         * <p>Das folgende Schemafragment gibt den erwarteten Content an, der in dieser Klasse enthalten ist.</p>
         * 
         * <pre>{@code
         * <complexType>
         *   <complexContent>
         *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
         *       <attribute name="name" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
         *       <attribute name="variable" use="required" type="{http://www.w3.org/2001/XMLSchema}string" />
         *     </restriction>
         *   </complexContent>
         * </complexType>
         * }</pre>
         * 
         * 
         */
        @XmlAccessorType(XmlAccessType.FIELD)
        @XmlType(name = "")
        public static class Header {

            @XmlAttribute(name = "name", required = true)
            protected String name;
            @XmlAttribute(name = "variable", required = true)
            protected String variable;

            /**
             * Ruft den Wert der name-Eigenschaft ab.
             * 
             * @return
             *     possible object is
             *     {@link String }
             *     
             */
            public String getName() {
                return name;
            }

            /**
             * Legt den Wert der name-Eigenschaft fest.
             * 
             * @param value
             *     allowed object is
             *     {@link String }
             *     
             */
            public void setName(String value) {
                this.name = value;
            }

            /**
             * Ruft den Wert der variable-Eigenschaft ab.
             * 
             * @return
             *     possible object is
             *     {@link String }
             *     
             */
            public String getVariable() {
                return variable;
            }

            /**
             * Legt den Wert der variable-Eigenschaft fest.
             * 
             * @param value
             *     allowed object is
             *     {@link String }
             *     
             */
            public void setVariable(String value) {
                this.variable = value;
            }

        }

    }

}
